# gbquality

This is a python "translation" of the original MATLAB code for the Q <sub>GB</sub> measure of global quality assessment
 of Non-Linear Dimensionality Reduction (NLDR). 

The [original paper](https://doi.org/10.1016/j.neucom.2010.10.011) (author-provided [PDF](http://gr.xjtu.edu.cn/c/document_library/get_file?folderId=495355&name=DLFE-8842.pdf)) should be cited:

    Please cite: "Deyu Meng, Yee Leung, Zongben Xu.
    A new quality assessment criterion for nonlinear dimensionality reduction, Neurocomputing, 2011, 74(6): 941-948."

The [MATLAB code](http://gr.xjtu.edu.cn/c/document_library/get_file?folderId=495355&name=DLFE-8841.rar) 
was written by [Deyu Meng](http://www.cs.cmu.edu/~deyum/Publications.htm). The Python code is an  adaptation by Andrew Lensen.

The code is packaged as gbquality on [pypi](https://pypi.org/project/gbquality/) and so can be installed in the normal way with `pip install gbquality`